aboutsummaryrefslogtreecommitdiff
path: root/app/src/main/java/xyz/adjutor/aniki/anime
diff options
context:
space:
mode:
Diffstat (limited to 'app/src/main/java/xyz/adjutor/aniki/anime')
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/AnimeApi.kt2
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/AnimeResponse.kt (renamed from app/src/main/java/xyz/adjutor/aniki/anime/RestAnimeResponse.kt)6
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/search/DetailSearchAnimeActivity.kt156
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnime.kt31
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeAdapter.kt81
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeApi.kt12
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimePage.kt119
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeResponse.kt13
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/topanime/DetailTopAnimeActivity.kt34
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeApi.kt2
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimePage.kt34
-rw-r--r--app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeResponse.kt (renamed from app/src/main/java/xyz/adjutor/aniki/anime/topanime/RestTopAnimeResponse.kt)2
12 files changed, 455 insertions, 37 deletions
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/AnimeApi.kt b/app/src/main/java/xyz/adjutor/aniki/anime/AnimeApi.kt
index 028097a..52ca2ba 100644
--- a/app/src/main/java/xyz/adjutor/aniki/anime/AnimeApi.kt
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/AnimeApi.kt
@@ -7,6 +7,6 @@ import retrofit2.http.Path
interface AnimeApi {
@GET("v3/anime/{id}")
- fun getAnimeData(@Path("id") id: String): Call<RestAnimeResponse>
+ fun getAnimeData(@Path("id") id: String): Call<AnimeResponse>
} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/RestAnimeResponse.kt b/app/src/main/java/xyz/adjutor/aniki/anime/AnimeResponse.kt
index b449b31..9e279e1 100644
--- a/app/src/main/java/xyz/adjutor/aniki/anime/RestAnimeResponse.kt
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/AnimeResponse.kt
@@ -2,11 +2,15 @@ package xyz.adjutor.aniki.anime
import com.google.gson.annotations.SerializedName
-class RestAnimeResponse { //only kept the infos I didn't have and that were interesting to me.
+class AnimeResponse { //only kept the infos I didn't have and that were interesting to me.
@SerializedName("mal_id")
var mal_id: Int? = null
+ @SerializedName("rank")
+ var rank: Int? = null //added for the search feature (detail)
+
@SerializedName("synopsis")
var synopsis: String? = null
+
}
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/search/DetailSearchAnimeActivity.kt b/app/src/main/java/xyz/adjutor/aniki/anime/search/DetailSearchAnimeActivity.kt
new file mode 100644
index 0000000..2f4a6c2
--- /dev/null
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/search/DetailSearchAnimeActivity.kt
@@ -0,0 +1,156 @@
+package xyz.adjutor.aniki.anime.search
+
+import android.os.Bundle
+import android.widget.ImageView
+import android.widget.TextView
+import android.widget.Toast
+import androidx.appcompat.app.AppCompatActivity
+import com.bumptech.glide.Glide
+import com.bumptech.glide.request.RequestOptions
+import com.google.gson.GsonBuilder
+import retrofit2.Call
+import retrofit2.Callback
+import retrofit2.Response
+import retrofit2.Retrofit
+import retrofit2.converter.gson.GsonConverterFactory
+import xyz.adjutor.aniki.R
+import xyz.adjutor.aniki.anime.AnimeApi
+import xyz.adjutor.aniki.anime.AnimeResponse
+
+class DetailSearchAnimeActivity : AppCompatActivity() {
+
+ private var baseUrl = "https://api.jikan.moe/"
+ private val gson = GsonBuilder()
+ .setLenient()
+ .create()
+
+ //used in the list
+ private val intentAnimeImageUrl = "theanimeimageurl"
+ private val intentAnimeTitle = "theanimetitle"
+ private val intentAnimeScore = "theanimescore"
+
+ //only used for the detail
+ private val intentAnimeId = "theanimeid"
+ private val intentAnimeUrl = "theanimeurl"
+ private val intentAnimeEpisodes = "theanimeepisodes"
+ private val intentAnimeStartDate = "theanimestartdate"
+ private val intentAnimeEndDate = "theanimeenddate"
+
+ override fun onCreate(savedInstanceState: Bundle?) {
+ super.onCreate(savedInstanceState)
+ setContentView(R.layout.activity_detail_search_anime)
+
+ val animeImageUrl = intent.getStringExtra(intentAnimeImageUrl)
+ val animeTitle = intent.getStringExtra(intentAnimeTitle)
+ val animeScore = intent.getStringExtra(intentAnimeScore)
+
+ val animeId = intent.getStringExtra(intentAnimeId)
+ val animeUrl = intent.getStringExtra(intentAnimeUrl)
+ val animeEpisodes = intent.getStringExtra(intentAnimeEpisodes)
+ val animeStartDate = intent.getStringExtra(intentAnimeStartDate)
+ val animeEndDate = intent.getStringExtra(intentAnimeEndDate)
+
+
+ val ivImage: ImageView = findViewById(R.id.iv_detail_image)
+ val tvTitle: TextView = findViewById(R.id.tv_detail_title)
+ val tvScore: TextView = findViewById(R.id.tv_detail_score)
+
+ val tvId: TextView = findViewById(R.id.tv_detail_id)
+ val tvUrl: TextView = findViewById(R.id.tv_url)
+ val tvEpisodes: TextView = findViewById(R.id.tv_episodes)
+ val tvStartDate: TextView = findViewById(R.id.tv_start_date)
+ val tvEndDate: TextView = findViewById(R.id.tv_end_date)
+
+ Glide
+ .with(this)
+ .load(animeImageUrl)
+ .apply(RequestOptions().override(400))
+ .into(ivImage)
+ tvTitle.text = animeTitle
+ tvScore.text = animeScore
+
+
+ tvId.text = animeId
+ tvUrl.text = animeUrl
+
+ //using null as a string because it has been converted to a string before
+ tvEpisodes.text = if (animeEpisodes != "null") {
+ animeEpisodes
+ } else {
+ fieldIsNull()
+ }
+
+ tvStartDate.text = splitDate(animeStartDate!!)
+
+ tvEndDate.text = if (animeEndDate != "null") {
+ splitDate(animeEndDate!!)
+ } else {
+ fieldIsNull()
+ }
+
+ makeApiCall(baseUrl, animeId.toString())
+
+ }
+
+ private fun splitDate(animeDate: String): CharSequence {
+ val delimiter = "T"
+ return animeDate
+ .split(delimiter) //split between the date and the time
+ .toTypedArray()[0] //convert it to an array and take the first string
+
+ }
+
+ private fun makeApiCall(
+ BASE_URL: String,
+ animeId: String
+ ) { //we take the rest of the data that we need from the internet
+
+ val retrofit = Retrofit.Builder()
+ .baseUrl(BASE_URL)
+ .addConverterFactory(GsonConverterFactory.create(gson))
+ .build()
+
+ val service = retrofit.create(AnimeApi::class.java)
+ val call = service.getAnimeData(animeId) //based on the id
+
+ call.enqueue(object : Callback<AnimeResponse> {
+ override fun onResponse(
+ call: Call<AnimeResponse>,
+ response: Response<AnimeResponse>
+ ) {
+ if (response.isSuccessful && response.body() != null) { //if the code returned is >= 200 and < 300 AND the the body ain't empty
+
+ val anime = response.body() //getting the AnimeResponse fields
+ showDetail(anime!!)
+
+ } else {
+ showError("API ERROR : is not successful")
+ }
+ }
+
+ override fun onFailure(call: Call<AnimeResponse>, t: Throwable) {
+ showError("API ERROR : onFailure")
+ }
+
+ })
+ }
+
+ private fun showDetail(anime: AnimeResponse) {
+ //elements from AnimeResponse
+ val tvSynopsis: TextView = findViewById(R.id.tv_synopsis)
+ val tvRank: TextView = findViewById(R.id.tv_detail_rank)
+
+ tvSynopsis.text = anime.synopsis.toString()
+
+ tvRank.text = anime.rank.toString()
+
+ }
+
+ fun showError(text: String) {
+ Toast.makeText(this, text, Toast.LENGTH_LONG).show()
+ }
+
+ private fun fieldIsNull(): String {
+ return "Unknown"
+ }
+} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnime.kt b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnime.kt
new file mode 100644
index 0000000..ad7b7eb
--- /dev/null
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnime.kt
@@ -0,0 +1,31 @@
+package xyz.adjutor.aniki.anime.search
+
+import com.google.gson.annotations.SerializedName
+
+class SearchAnime {
+
+ @SerializedName("mal_id")
+ var mal_id: Int? = null
+
+ @SerializedName("url")
+ var url: String? = null
+
+ @SerializedName("image_url")
+ var image_url: String? = null
+
+ @SerializedName("title")
+ var title: String? = null
+
+ @SerializedName("episodes")
+ var episodes: Int? = null
+
+ @SerializedName("score")
+ var score: Float? = null
+
+ @SerializedName("start_date") //we'll maybe remove this later
+ var start_date: String? = null
+
+ @SerializedName("end_date") //we'll maybe remove this later
+ var end_date: String? = null
+
+} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeAdapter.kt b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeAdapter.kt
new file mode 100644
index 0000000..78718dd
--- /dev/null
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeAdapter.kt
@@ -0,0 +1,81 @@
+package xyz.adjutor.aniki.anime.search
+
+import android.content.Intent
+import android.view.LayoutInflater
+import android.view.View
+import android.view.ViewGroup
+import android.widget.ImageView
+import android.widget.TextView
+import androidx.cardview.widget.CardView
+import androidx.recyclerview.widget.RecyclerView
+import com.bumptech.glide.Glide
+import com.bumptech.glide.request.RequestOptions
+import xyz.adjutor.aniki.R
+
+class SearchAnimeAdapter(private val animeList: List<SearchAnime>) :
+ RecyclerView.Adapter<SearchAnimeAdapter.AnimeViewHolder>() {
+
+ // Describes an item view and its place within the RecyclerView
+ class AnimeViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
+ val animeTitle: TextView = itemView.findViewById(R.id.tv_title)
+ val animeRank: TextView = itemView.findViewById(R.id.tv_rank)
+ val animeScore: TextView = itemView.findViewById(R.id.tv_score)
+ val animeImage: ImageView = itemView.findViewById(R.id.iv_image)
+ val cardview: CardView = itemView.findViewById(R.id.cv_cardView)
+ }
+
+ // Returns a new ViewHolder
+ override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): AnimeViewHolder {
+ val view = LayoutInflater.from(parent.context)
+ .inflate(R.layout.item_layout, parent, false)
+
+ return AnimeViewHolder(view)
+ }
+
+ // Returns size of data list
+ override fun getItemCount(): Int {
+ return animeList.size
+ }
+
+ // Displays data at a certain position
+ override fun onBindViewHolder(holder: AnimeViewHolder, position: Int) {
+ val currentAnime: SearchAnime = animeList[position]
+ holder.animeTitle.text = currentAnime.title
+ holder.animeRank.text = "" //the rank isn't supplied by this API
+ holder.animeScore.text = currentAnime.score.toString()
+ val image: String = currentAnime.image_url.toString()
+ Glide
+ .with(holder.itemView.context)
+ .load(image)
+ .apply(RequestOptions().override(400))
+ .into(holder.animeImage)
+
+ //when you click on a selected cardview, some datas are sent to the other activity
+ holder.cardview.setOnClickListener {
+ val currentAnimeId = "theanimeid"
+ val currentAnimeUrl = "theanimeurl"
+ val currentAnimeImageUrl = "theanimeimageurl"
+ val currentAnimeTitle = "theanimetitle"
+ val currentAnimeEpisodes = "theanimeepisodes"
+ val currentAnimeScore = "theanimescore"
+ val currentAnimeStartDate = "theanimestartdate"
+ val currentAnimeEndDate = "theanimeenddate"
+
+ //intent is used to pass data to another activity
+
+ val intent: Intent =
+ Intent(holder.itemView.context, DetailSearchAnimeActivity::class.java).apply {
+ putExtra(currentAnimeId, currentAnime.mal_id.toString())
+ putExtra(currentAnimeUrl, currentAnime.url.toString())
+ putExtra(currentAnimeImageUrl, currentAnime.image_url.toString())
+ putExtra(currentAnimeTitle, currentAnime.title)
+ putExtra(currentAnimeEpisodes, currentAnime.episodes.toString())
+ putExtra(currentAnimeScore, currentAnime.score.toString())
+ putExtra(currentAnimeStartDate, currentAnime.start_date)
+ putExtra(currentAnimeEndDate, currentAnime.end_date.toString())
+ }
+ holder.itemView.context.startActivity(intent)
+ }
+
+ }
+} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeApi.kt b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeApi.kt
new file mode 100644
index 0000000..5512636
--- /dev/null
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeApi.kt
@@ -0,0 +1,12 @@
+package xyz.adjutor.aniki.anime.search
+
+import retrofit2.Call
+import retrofit2.http.GET
+import retrofit2.http.Query
+
+interface SearchAnimeApi {
+
+ @GET("v3/search/anime")
+ fun getSearchAnimeData(@Query("q") q: String): Call<SearchAnimeResponse>
+
+} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimePage.kt b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimePage.kt
new file mode 100644
index 0000000..c1596c3
--- /dev/null
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimePage.kt
@@ -0,0 +1,119 @@
+package xyz.adjutor.aniki.anime.search
+
+import android.content.Context
+import android.os.Bundle
+import android.view.LayoutInflater
+import android.view.View
+import android.view.ViewGroup
+import android.view.inputmethod.InputMethodManager
+import android.widget.Button
+import androidx.fragment.app.Fragment
+import androidx.navigation.fragment.findNavController
+import androidx.recyclerview.widget.LinearLayoutManager
+import androidx.recyclerview.widget.RecyclerView
+import com.google.android.material.snackbar.Snackbar
+import com.google.android.material.textfield.TextInputEditText
+import com.google.gson.Gson
+import com.google.gson.GsonBuilder
+import retrofit2.Call
+import retrofit2.Callback
+import retrofit2.Response
+import retrofit2.Retrofit
+import retrofit2.converter.gson.GsonConverterFactory
+import xyz.adjutor.aniki.MainActivity
+import xyz.adjutor.aniki.R
+
+class SearchAnimePage : Fragment() {
+
+ val gson: Gson = GsonBuilder()
+ .setLenient()
+ .create()
+ private var baseUrl = "https://api.jikan.moe/" //the api's base url
+
+ override fun onCreateView(
+ inflater: LayoutInflater, container: ViewGroup?,
+ savedInstanceState: Bundle?
+ ): View? {
+ // Inflate the layout for this fragment
+
+ return inflater.inflate(R.layout.search_anime_page, container, false)
+ }
+
+
+ override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
+ super.onViewCreated(view, savedInstanceState)
+
+ //button to return to the home page
+ view.findViewById<Button>(R.id.button_home).setOnClickListener {
+ findNavController().navigate(R.id.action_SearchAnimePage_to_HomePage)
+ }
+
+ view.findViewById<Button>(R.id.button_query).setOnClickListener{
+ val userInput = view.findViewById<TextInputEditText>(R.id.tiet_query).text.toString()
+ hideKeyboard()
+ makeApiCall(view, baseUrl, userInput)
+ }
+ }
+
+ private fun hideKeyboard() {
+ val activity = activity as MainActivity
+
+ val view = activity.currentFocus
+ if (view != null) {
+ val imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE) as InputMethodManager
+ imm.hideSoftInputFromWindow(view.windowToken, 0)
+ }
+ }
+
+ //display the recyclerview
+ fun showList(view: View, animeList: List<SearchAnime>) {
+ val recyclerView: RecyclerView = view.findViewById(R.id.recycler_view)
+ recyclerView.setHasFixedSize(true)
+ recyclerView.layoutManager = LinearLayoutManager(view.context)
+ recyclerView.adapter = SearchAnimeAdapter(animeList)
+ (recyclerView.adapter as SearchAnimeAdapter).notifyDataSetChanged()
+ }
+
+ private fun makeApiCall(view: View, BASE_URL: String, query: String) {
+
+ val retrofit = Retrofit.Builder()
+ .baseUrl(BASE_URL)
+ .addConverterFactory(GsonConverterFactory.create(gson))
+ .build()
+
+ val service = retrofit.create(SearchAnimeApi::class.java)
+ val call = service.getSearchAnimeData(q = query) //fate is an exemple, we'll have to replace it by the user input.
+
+ call.enqueue(object : Callback<SearchAnimeResponse> {
+ override fun onResponse(
+ call: Call<SearchAnimeResponse>,
+ response: Response<SearchAnimeResponse>
+ ) {
+ if (response.isSuccessful && response.body() != null) { //if the code returned is >= 200 and < 300 AND the the body ain't empty
+
+ val animeList: List<SearchAnime> = response.body()!!
+ .getResults() //getting the "search" field containing our list of SearchAnimes
+
+ showList(
+ view,
+ animeList
+ ) //calling the method in charge of displaying on the recyclerview
+
+ } else {
+ showError() //a snackbar
+ }
+ }
+
+ override fun onFailure(call: Call<SearchAnimeResponse>, t: Throwable) {
+ showError()
+ }
+
+ })
+ }
+
+ private fun showError() {
+ Snackbar.make(requireView(), "API ERROR : Verify your internet connection or your query.", Snackbar.LENGTH_LONG)
+ .setAction("Action", null).show()
+ }
+
+} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeResponse.kt b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeResponse.kt
new file mode 100644
index 0000000..92100ba
--- /dev/null
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/search/SearchAnimeResponse.kt
@@ -0,0 +1,13 @@
+package xyz.adjutor.aniki.anime.search
+
+import com.google.gson.annotations.SerializedName
+
+class SearchAnimeResponse { //only kept the infos I didn't have and that were interesting to me.
+
+ @SerializedName("results")
+ private lateinit var results: List<SearchAnime>
+
+ fun getResults(): List<SearchAnime> {
+ return results
+ }
+}
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeApi.kt b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeApi.kt
index a5b3b59..8e44e77 100644
--- a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeApi.kt
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeApi.kt
@@ -6,6 +6,6 @@ import retrofit2.http.GET
interface TopAnimeApi {
@GET("v3/top/anime")
- fun getTopAnimeData(): Call<RestTopAnimeResponse>
+ fun getTopAnimeData(): Call<TopAnimeResponse>
} \ No newline at end of file
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimePage.kt b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimePage.kt
index ccae2fa..d62e5b2 100644
--- a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimePage.kt
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimePage.kt
@@ -13,6 +13,7 @@ import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
import com.google.android.material.snackbar.Snackbar
+import com.google.gson.Gson
import com.google.gson.GsonBuilder
import com.google.gson.reflect.TypeToken
import retrofit2.Call
@@ -25,11 +26,11 @@ import java.lang.reflect.Type
class TopAnimePage : Fragment() {
- var sharedPreferences: SharedPreferences? = null
- val gson = GsonBuilder()
+ private lateinit var sharedPreferences: SharedPreferences
+ val gson: Gson = GsonBuilder()
.setLenient()
.create()
- var base_url = "https://api.jikan.moe/" //the api's base url
+ var baseUrl = "https://api.jikan.moe/" //the api's base url
override fun onCreateView(
inflater: LayoutInflater, container: ViewGroup?,
@@ -44,7 +45,7 @@ class TopAnimePage : Fragment() {
if (animeList != null) {
showList(view, animeList)
} else {
- makeApiCall(view, base_url)
+ makeApiCall(view, baseUrl)
}
return view
@@ -52,14 +53,14 @@ class TopAnimePage : Fragment() {
private fun getDataFromCache(): List<TopAnime>? {
//the value of the animeList json, if nothing is found, return null
- val jsonAnime: String? = sharedPreferences?.getString("jsonAnimeList", null)
+ val jsonAnime: String? = sharedPreferences.getString("jsonAnimeList", null)
//if it's null, well, return null
- if (jsonAnime == null) {
- return null
+ return if (jsonAnime == null) {
+ null
} else { //else deserialize the list and return it
val listType: Type = object : TypeToken<List<TopAnime>>() {}.type
- return gson.fromJson(jsonAnime, listType)
+ gson.fromJson(jsonAnime, listType)
}
}
@@ -72,7 +73,7 @@ class TopAnimePage : Fragment() {
}
fun updateList() {
- makeApiCall(view, base_url)
+ makeApiCall(view, baseUrl)
Snackbar.make(requireView(), "Data refreshed", Snackbar.LENGTH_LONG)
.setAction("Action", null).show()
}
@@ -91,6 +92,7 @@ class TopAnimePage : Fragment() {
recyclerView.setHasFixedSize(true)
recyclerView.layoutManager = LinearLayoutManager(view.context)
recyclerView.adapter = TopAnimeAdapter(animeList)
+ (recyclerView.adapter as TopAnimeAdapter).notifyDataSetChanged()
}
private fun makeApiCall(view: View, BASE_URL: String) {
@@ -103,10 +105,10 @@ class TopAnimePage : Fragment() {
val service = retrofit.create(TopAnimeApi::class.java)
val call = service.getTopAnimeData()
- call.enqueue(object : Callback<RestTopAnimeResponse> {
+ call.enqueue(object : Callback<TopAnimeResponse> {
override fun onResponse(
- call: Call<RestTopAnimeResponse>,
- response: Response<RestTopAnimeResponse>
+ call: Call<TopAnimeResponse>,
+ response: Response<TopAnimeResponse>
) {
if (response.isSuccessful && response.body() != null) { //if the code returned is >= 200 and < 300 AND the the body ain't empty
@@ -123,7 +125,7 @@ class TopAnimePage : Fragment() {
}
}
- override fun onFailure(call: Call<RestTopAnimeResponse>, t: Throwable) {
+ override fun onFailure(call: Call<TopAnimeResponse>, t: Throwable) {
showError()
}
@@ -134,9 +136,9 @@ class TopAnimePage : Fragment() {
val jsonString: String = gson.toJson(animeList)
sharedPreferences
- ?.edit()
- ?.putString("jsonAnimeList", jsonString)
- ?.apply()
+ .edit()
+ .putString("jsonAnimeList", jsonString)
+ .apply()
}
private fun showError() {
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/RestTopAnimeResponse.kt b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeResponse.kt
index edc11cf..2fe69d6 100644
--- a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/RestTopAnimeResponse.kt
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/TopAnimeResponse.kt
@@ -2,7 +2,7 @@ package xyz.adjutor.aniki.anime.topanime
import com.google.gson.annotations.SerializedName
-class RestTopAnimeResponse {
+class TopAnimeResponse {
@SerializedName("top")
var top: List<TopAnime>? = null
diff --git a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/DetailTopAnimeActivity.kt b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/DetailTopAnimeActivity.kt
index acbbd4d..661937f 100644
--- a/app/src/main/java/xyz/adjutor/aniki/anime/topanime/DetailTopAnimeActivity.kt
+++ b/app/src/main/java/xyz/adjutor/aniki/anime/topanime/DetailTopAnimeActivity.kt
@@ -18,13 +18,13 @@ import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import xyz.adjutor.aniki.R
import xyz.adjutor.aniki.anime.AnimeApi
-import xyz.adjutor.aniki.anime.RestAnimeResponse
+import xyz.adjutor.aniki.anime.AnimeResponse
import java.lang.reflect.Type
class DetailTopAnimeActivity : AppCompatActivity() {
private var baseUrl = "https://api.jikan.moe/"
- var sharedPreferences: SharedPreferences? = null
+ private lateinit var sharedPreferences: SharedPreferences
private val gson = GsonBuilder()
.setLenient()
.create()
@@ -95,7 +95,7 @@ class DetailTopAnimeActivity : AppCompatActivity() {
tvUrl.text = animeUrl
- val anime: RestAnimeResponse? = getDataFromCache(animeId.toString())
+ val anime: AnimeResponse? = getDataFromCache(animeId.toString())
if (anime != null) {
showDetail(anime)
} else {
@@ -105,13 +105,13 @@ class DetailTopAnimeActivity : AppCompatActivity() {
}
- private fun getDataFromCache(animeId: String): RestAnimeResponse? {
- val jsonAnime: String? = sharedPreferences?.getString(animeId, null)
+ private fun getDataFromCache(animeId: String): AnimeResponse? {
+ val jsonAnime: String? = sharedPreferences.getString(animeId, null)
return if (jsonAnime == null) {
null
} else {
- val type: Type = object : TypeToken<RestAnimeResponse>() {}.type
+ val type: Type = object : TypeToken<AnimeResponse>() {}.type
gson.fromJson(jsonAnime, type)
}
}
@@ -126,14 +126,14 @@ class DetailTopAnimeActivity : AppCompatActivity() {
val service = retrofit.create(AnimeApi::class.java)
val call = service.getAnimeData(animeId) //based on the id
- call.enqueue(object : Callback<RestAnimeResponse> {
+ call.enqueue(object : Callback<AnimeResponse> {
override fun onResponse(
- call: Call<RestAnimeResponse>,
- response: Response<RestAnimeResponse>
+ call: Call<AnimeResponse>,
+ response: Response<AnimeResponse>
) {
if (response.isSuccessful && response.body() != null) { //if the code returned is >= 200 and < 300 AND the the body ain't empty
- val anime = response.body() //getting the RestAnimeResponse fields
+ val anime = response.body() //getting the AnimeResponse fields
saveList(anime)
showDetail(anime!!)
@@ -142,15 +142,15 @@ class DetailTopAnimeActivity : AppCompatActivity() {
}
}
- override fun onFailure(call: Call<RestAnimeResponse>, t: Throwable) {
+ override fun onFailure(call: Call<AnimeResponse>, t: Throwable) {
showError("API ERROR : onFailure")
}
})
}
- private fun showDetail(anime: RestAnimeResponse) {
- //elements from RestAnimeResponse
+ private fun showDetail(anime: AnimeResponse) {
+ //elements from AnimeResponse
val tvSynopsis: TextView = findViewById(R.id.tv_synopsis)
tvSynopsis.text = anime.synopsis.toString()
@@ -165,12 +165,12 @@ class DetailTopAnimeActivity : AppCompatActivity() {
return "Unknown"
}
- fun saveList(anime: RestAnimeResponse?) {
+ fun saveList(anime: AnimeResponse?) {
val jsonString: String = gson.toJson(anime)
sharedPreferences
- ?.edit()
- ?.putString(anime?.mal_id.toString(), jsonString)
- ?.apply()
+ .edit()
+ .putString(anime?.mal_id.toString(), jsonString)
+ .apply()
}
} \ No newline at end of file